#!/usr/bin/env bash
cat > $1/demos/Makefile.am <<EOF
noinst_PROGRAMS = demo

demo_SOURCES = demo.c
demo_CPPFLAGS = \$(DEPS_CFLAGS) -I\$(top_srcdir)/src
demo_LDADD = \$(DEPS_LIBS) -L\$(top_builddir)/src -l${1#lib}
EOF
